# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.7.1](https://github.com/agntcy/slim/compare/slim-v0.7.0...slim-v0.7.1) - 2025-11-21

### Fixed

- flaky integration test ([#981](https://github.com/agntcy/slim/pull/981))
- early tracing initialization ([#978](https://github.com/agntcy/slim/pull/978))

## [0.7.0](https://github.com/agntcy/slim/compare/slim-v0.6.1...slim-v0.7.0) - 2025-11-17

### Added

- improve logging configuration ([#943](https://github.com/agntcy/slim/pull/943))

### Other

- *(data-plane)* update project dependencies ([#861](https://github.com/agntcy/slim/pull/861))

## [0.6.1](https://github.com/agntcy/slim/compare/slim-v0.6.0...slim-v0.6.1) - 2025-10-17

### Other

- update Cargo.lock dependencies

## [0.6.0](https://github.com/agntcy/slim/compare/slim-v0.5.0...slim-v0.6.0) - 2025-10-09

### Other

- updated the following local packages: agntcy-slim-config, agntcy-slim-tracing, agntcy-slim-service

## [0.5.0](https://github.com/agntcy/slim/compare/slim-v0.4.0...slim-v0.5.0) - 2025-09-17

### Fixed

- use duration-string in place of duration-str ([#683](https://github.com/agntcy/slim/pull/683))

## [0.4.0](https://github.com/agntcy/slim/compare/slim-v0.3.15...slim-v0.4.0) - 2025-07-31

### Other

- remove Agent and AgentType and adopt Name as application identifier ([#477](https://github.com/agntcy/slim/pull/477))

## [0.3.15](https://github.com/agntcy/slim/compare/slim-v0.3.14...slim-v0.3.15) - 2025-05-14

### Fixed

- *(mcp-proxy)* dependencies ([#252](https://github.com/agntcy/slim/pull/252))

## [0.3.14](https://github.com/agntcy/slim/compare/slim-v0.3.13...slim-v0.3.14) - 2025-05-14

### Other

- updated the following local packages: slim-service

## [0.3.13](https://github.com/agntcy/slim/compare/slim-v0.3.12...slim-v0.3.13) - 2025-05-14

### Other

- updated the following local packages: slim-config, slim-service, slim-tracing

## [0.3.12](https://github.com/agntcy/slim/compare/slim-v0.3.11...slim-v0.3.12) - 2025-04-24

### Added

- *(python-bindings)* improve configuration handling and further refactoring ([#167](https://github.com/agntcy/slim/pull/167))
- *(data-plane)* support for multiple servers ([#173](https://github.com/agntcy/slim/pull/173))

### Other

- declare all dependencies in workspace Cargo.toml ([#187](https://github.com/agntcy/slim/pull/187))
- upgrade to rust edition 2024 and toolchain 1.86.0 ([#164](https://github.com/agntcy/slim/pull/164))

## [0.3.11](https://github.com/agntcy/slim/compare/slim-v0.3.10...slim-v0.3.11) - 2025-04-08

### Other

- update copyright ([#109](https://github.com/agntcy/slim/pull/109))

## [0.3.10](https://github.com/agntcy/slim/compare/slim-v0.3.9...slim-v0.3.10) - 2025-03-19

### Other

- release ([#103](https://github.com/agntcy/slim/pull/103))

## [0.3.9](https://github.com/agntcy/slim/compare/slim-v0.3.8...slim-v0.3.9) - 2025-03-19

### Other

- updated the following local packages: slim-service

## [0.3.8](https://github.com/agntcy/slim/compare/slim-v0.3.7...slim-v0.3.8) - 2025-03-18

### Other

- updated the following local packages: slim-service

## [0.3.7](https://github.com/agntcy/slim/compare/slim-v0.3.6...slim-v0.3.7) - 2025-03-18

### Other

- update Cargo.lock dependencies

## [0.3.6](https://github.com/agntcy/slim/compare/slim-v0.3.5...slim-v0.3.6) - 2025-03-12

### Other

- updated the following local packages: slim-service

## [0.3.5](https://github.com/agntcy/slim/compare/slim-v0.3.4...slim-v0.3.5) - 2025-03-11

### Other

- *(slim-config)* release v0.1.4 ([#79](https://github.com/agntcy/slim/pull/79))

## [0.3.4](https://github.com/agntcy/slim/compare/slim-v0.3.3...slim-v0.3.4) - 2025-02-28

### Other

- updated the following local packages: slim-service

## [0.3.3](https://github.com/agntcy/slim/compare/slim-v0.3.2...slim-v0.3.3) - 2025-02-28

### Added

- add message handling metrics

## [0.3.2](https://github.com/agntcy/slim/compare/slim-v0.3.1...slim-v0.3.2) - 2025-02-24

### Other

- update Cargo.lock dependencies

## [0.3.1](https://github.com/agntcy/slim/compare/slim-v0.3.0...slim-v0.3.1) - 2025-02-20

### Other

- release (#58)

## [0.3.0](https://github.com/agntcy/slim/compare/slim-v0.2.1...slim-v0.3.0) - 2025-02-14

### Added

- add build info to main SLIM executable (#35)

## [0.2.1](https://github.com/agntcy/slim/compare/slim-v0.2.0...slim-v0.2.1) - 2025-02-14

### Added

- implement opentelemetry tracing subscriber

## [0.2.0](https://github.com/agntcy/slim/compare/slim-v0.1.0...slim-v0.2.0) - 2025-02-12

### Fixed

- *(slim)* remove unused log level (#28)

## [0.1.0](https://github.com/agntcy/slim/releases/tag/slim-v0.1.0) - 2025-02-10

### Added

- Stage the first commit of SLIM (#3)

### Other

- reduce the number of crates to publish (#10)
